View Source Cldr.DateTime (Cldr Dates & Times v2.19.1)
Provides localization and formatting of a datetime.
A date time is any DateTime.t/0 or NaiveDateTime.t/0
struct or any map that contains one or more of the keys :year, :month, :day,
:hour, :minute and :second or :microsecond with optional :time_zone, :zone_abbr,
:utc_offset, :std_offset and :calendar fields.
Cldr.DateTime provides support for the built-in calendar
Calendar.ISO or any calendars defined with
ex_cldr_calendars
CLDR provides standard format strings for DateTime.t/0 which
are represented by the names :short, :medium, :long
and :full. This allows for locale-independent
formatting since each locale and calendar will define the underlying
format string as appropriate.
Summary
Functions
Guards whether the given datetime has components of a date.
Guard whether the given datetime has components of both a date and a time.
Guards whether the given datetime has components of a time.
Indicates if a given map fulfills the requirements for a naive date time or date time.
Indicates if a given map fulfills the requirements for a date time.
Indicates if a given map fulfills the requirements for a naive date time.
Formats a DateTime according to a format string as defined in CLDR and described in TR35.
Formats a DateTime according to a format string as defined in CLDR and described in TR35 returning a formatted string or raising on error.
Functions
Guards whether the given datetime has components of a date.
Guard whether the given datetime has components of both a date and a time.
Guards whether the given datetime has components of a time.
Indicates if a given map fulfills the requirements for a naive date time or date time.
Indicates if a given map fulfills the requirements for a date time.
Indicates if a given map fulfills the requirements for a naive date time.
to_string(datetime, backend \\ Cldr.Date.default_backend(), options \\ [])
View Source@spec to_string( Cldr.Calendar.any_date_time(), Cldr.backend() | Keyword.t(), Keyword.t() ) :: {:ok, String.t()} | {:error, {module(), String.t()}}
Formats a DateTime according to a format string as defined in CLDR and described in TR35.
Arguments
datetimeis aDateTime.t/0orNaiveDateTime.t/0struct or any map that contains one or more of the keys:year,:month,:day,:hour,:minuteand:secondor:microsecondwith optional:time_zone,:zone_abbr,:utc_offset,:std_offsetand:calendarfields.backendis any module that includesuse Cldrand therefore is aCldrbackend module. The default isCldr.default_backend!/0.optionsis a keyword list of options for formatting.
Options
:formatis one of:short,:medium,:long,:fullor a format string or any of the keys in the map returned byCldr.DateTime.Format.date_time_formats/3. The default is:medium. See here for more information about specifying formats.:date_formatis any one of:short,:medium,:long,:full. If defined, this option is used to format the date part of the date time. This option is only acceptable if the:formatoption is not specified, or is specified as either:short,:medium,:long,:full. If:date_formatis not specified then the date format is defined by the:formatoption.:time_formatis any one of:short,:medium,:long,:full. If defined, this option is used to format the time part of the date time. This option is only acceptable if the:formatoption is not specified, or is specified as either:short,:medium,:long,:full. If:time_formatis not specified then the time format is defined by the:formatoption.:styleis either:ator:default. When set to:atthe datetime may be formatted with a localised string representing<date> at <time>if such a format exists. SeeCldr.DateTime.Format.date_time_at_formats/2.:preferis either:unicode(the default) or:ascii. A small number of formats have two variants - one using Unicode spaces (typically non-breaking space) and another using only ASCII whitespace. The:asciiformat is primarily to support legacy use cases and is not recommended. SeeCldr.DateTime.Format.date_time_available_formats/3to see which formats have these variants.:localeis any valid locale name returned byCldr.known_locale_names/0or aCldr.LanguageTag.t/0struct. The default isCldr.get_locale/0.:number_systema number system into which the formatted datetime digits should be transliterated.:erawhich, if set to:variant, will use a variant for the era if one is available in the requested locale. In the:enlocale, for example,era: :variantwill returnCEinstead ofADandBCEinstead ofBC.period: :variantwill use a variant for the time period and flexible time period if one is available in the locale. For example, in the:enlocaleperiod: :variantwill return "pm" instead of "PM".
Notes
If the provided
datetimecontains only date fields, the call is delegated toCldr.Date.to_string/2.If the provided
datetimecontains only time fields, the call is delegated toCldr.Time.to_string/2.
Returns
{:ok, formatted_datetime}or{:error, reason}
Examples
iex> {:ok, date_time} = DateTime.from_naive(~N[2000-01-01 23:59:59.0], "Etc/UTC")
iex> Cldr.DateTime.to_string(date_time)
{:ok, "Jan 1, 2000, 11:59:59 PM"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, locale: :en)
{:ok, "Jan 1, 2000, 11:59:59 PM"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :long, locale: :en)
{:ok, "January 1, 2000, 11:59:59 PM UTC"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :hms, locale: :en)
{:ok, "11:59:59 PM"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :full, locale: :en)
{:ok, "Saturday, January 1, 2000, 11:59:59 PM GMT"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :full, locale: :fr)
{:ok, "samedi 1 janvier 2000, 23:59:59 UTC"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :full, style: :at, locale: :en)
{:ok, "Saturday, January 1, 2000 at 11:59:59 PM GMT"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :full, style: :at, locale: :fr)
{:ok, "samedi 1 janvier 2000 à 23:59:59 UTC"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :MMMMW, locale: :fr)
{:ok, "semaine 1 (janvier)"}
iex> Cldr.DateTime.to_string(date_time, MyApp.Cldr, format: :yw, locale: :fr)
{:ok, "semaine 1 de 2000"}
to_string!(datetime, backend \\ Cldr.Date.default_backend(), options \\ [])
View Source@spec to_string!( Cldr.Calendar.any_date_time(), Cldr.backend() | Keyword.t(), Keyword.t() ) :: String.t() | no_return()
Formats a DateTime according to a format string as defined in CLDR and described in TR35 returning a formatted string or raising on error.
Arguments
datetimeis aDateTime.t/0orNaiveDateTime.t/0struct or any map that contains one or more of the keys:year,:month,:day,:hour,:minuteand:secondor:microsecondwith optional:time_zone,:zone_abbr,:utc_offset,:std_offsetand:calendarfields.backendis any module that includesuse Cldrand therefore is aCldrbackend module. The default isCldr.default_backend!/0.optionsis a keyword list of options for formatting.
Options
:formatis one of:short,:medium,:long,:fullor a format string or any of the keys returned byCldr.DateTime.Format.date_time_formats/3. The default is:medium. See here for more information about specifying formats.:styleis either:ator:default. When set to:atthe datetime may be formatted with a localised string representing<date> at <time>if such a format exists. SeeCldr.DateTime.Format.date_time_at_formats/2.:preferis either:unicode(the default) or:ascii. A small number of datetime formats have two variants - one using Unicode spaces (typically non-breaking space) and another using only ASCII whitespace. The:asciiformat is primarily to support legacy use cases and is not recommended. SeeCldr.DateTime.Format.date_time_available_formats/2to see which formats have these variants.:localeis any valid locale name returned byCldr.known_locale_names/0or aCldr.LanguageTag.t/0struct. The default isCldr.get_locale/0.:number_systema number system into which the formatted datetime digits should be transliterated.:erawhich, if set to:variant, will use a variant for the era if one is available in the requested locale. In the:enlocale, for example,era: :variantwill returnCEinstead ofADandBCEinstead ofBC.period: :variantwill use a variant for the time period and flexible time period if one is available in the locale. For example, in the:enlocaleperiod: :variantwill return "pm" instead of "PM".
Notes
If the provided
datetimecontains only date fields, the call is delegated toCldr.Date.to_string/2.If the provided
datetimecontains only time fields, the call is delegated toCldr.Time.to_string/2.
Returns
formatted_datetimeorraises an exception
Examples
iex> {:ok, date_time} = DateTime.from_naive(~N[2000-01-01 23:59:59.0], "Etc/UTC")
iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, locale: :en)
"Jan 1, 2000, 11:59:59 PM"
iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :long, locale: :en)
"January 1, 2000, 11:59:59 PM UTC"
iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :full, locale: :en)
"Saturday, January 1, 2000, 11:59:59 PM GMT"
iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :full, locale: :fr)
"samedi 1 janvier 2000, 23:59:59 UTC"
iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :MMMMW, locale: :fr)
"semaine 1 (janvier)"
iex> Cldr.DateTime.to_string!(date_time, MyApp.Cldr, format: :yw, locale: :fr)
"semaine 1 de 2000"