Cldr.DateTime.FormatError exception (Cldr Dates & Times v2.25.5)

Copy Markdown View Source

Exception raised when attempting to format a date or time which does not have the data available to fulfill the format.