Cldr.DateTime.NoTerritoryForTimezone exception (Cldr Dates & Times v2.25.5)

Copy Markdown View Source

Exception raised when an attempt is made to get the territory for a time zone and it has none - like "UTC"